==> querydsl-sql-4.2.1-sources.jar: com/querydsl/sql/types/DateTimeType.java <==
/*
 * Copyright 2015, The Querydsl Team (http://www.querydsl.com/team)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.querydsl.sql.types;

import java.sql.*;

import org.joda.time.DateTime;

/**
 * {@code DateTimeType} maps DateTime to Timestamp on the JDBC level
 *
 * @author tiwe
 *
 */
public class DateTimeType extends AbstractDateTimeType<DateTime> {

    public DateTimeType() {
        super(Types.TIMESTAMP);
    }

    public DateTimeType(int type) {
        super(type);
    }

    @Override
    public String getLiteral(DateTime value) {
        return dateTimeFormatter.print(value);
    }

    @Override
    public Class<DateTime> getReturnedClass() {
        return DateTime.class;
    }

    @Override
    public DateTime getValue(ResultSet rs, int startIndex) throws SQLException {
        Timestamp ts = rs.getTimestamp(startIndex);
        return ts != null ? new DateTime(ts.getTime()) : null;
    }

    @Override
    public void setValue(PreparedStatement st, int startIndex, DateTime value) throws SQLException {
        st.setTimestamp(startIndex, new Timestamp(value.getMillis()));
    }

}

==> querydsl-sql-5.1.0-sources.jar: com/querydsl/sql/types/DateTimeType.java <==
/*
 * Copyright 2015, The Querydsl Team (http://www.querydsl.com/team)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.querydsl.sql.types;

import java.sql.*;

import org.joda.time.DateTime;

/**
 * {@code DateTimeType} maps {@linkplain org.joda.time.DateTime}
 * to {@linkplain java.sql.Timestamp} on the JDBC level
 *
 * @author tiwe
 *
 */
public class DateTimeType extends AbstractJodaTimeDateTimeType<DateTime> {

    public DateTimeType() {
        super(Types.TIMESTAMP);
    }

    public DateTimeType(int type) {
        super(type);
    }

    @Override
    public String getLiteral(DateTime value) {
        return dateTimeFormatter.print(value);
    }

    @Override
    public Class<DateTime> getReturnedClass() {
        return DateTime.class;
    }

    @Override
    public DateTime getValue(ResultSet rs, int startIndex) throws SQLException {
        Timestamp ts = rs.getTimestamp(startIndex);
        return ts != null ? new DateTime(ts.getTime()) : null;
    }

    @Override
    public void setValue(PreparedStatement st, int startIndex, DateTime value) throws SQLException {
        st.setTimestamp(startIndex, new Timestamp(value.getMillis()));
    }

}
